@@ -42,7 +42,8 @@ use warnings;
 use App::CELL qw( $CELL $log $site );
 use App::Dochazka::REST::dbh;
 use App::Dochazka::REST::Dispatch::ACL qw( check_acl );
-use App::Dochazka::REST::Model::Employee;
+use App::Dochazka::REST::Model::Employee qw( noof_employees_by_priv );
+use App::Dochazka::REST::Model::Shared qw( noof );
 use Carp;
 use Data::Dumper;
 use Path::Router;
@@ -63,11 +64,11 @@ App::Dochazka::REST::Dispatch::Employee - path dispatch
 
 =head1 VERSION
 
-Version 0.117
+Version 0.122
 
 =cut
 
-our $VERSION = '0.117';
+our $VERSION = '0.122';
 
 
 
@@ -95,33 +96,68 @@ sub _init_get {
     die "Bad Path::Router object" unless $router_get->isa( 'Path::Router' );
 
     $router_get->add_route( 'employee',
+        defaults => {
+            'acl_profile' => 'passerby',
+        },
         target => \&_get_default,
     );
 
     $router_get->add_route( 'employee/help',
+        defaults => {
+            'acl_profile' => 'passerby',
+        },
         target => \&_get_default,
     );
 
     $router_get->add_route( 'employee/nick/:param',
+        defaults => {
+            'acl_profile' => 'admin',
+        },
         target => \&_get_nick,
     );
 
     $router_get->add_route( 'employee/eid/:param',
+        defaults => {
+            'acl_profile' => 'admin',
+        },
         target => \&_get_eid,
     );
 
     $router_get->add_route( 'employee/current',
+        defaults => {
+            'acl_profile' => 'passerby',
+        },
         target => \&_get_current,
     );
 
     $router_get->add_route( 'employee/logged_in',
+        defaults => {
+            'acl_profile' => 'passerby',
+        },
         target => \&_get_current,
     );
 
     $router_get->add_route( 'whoami',
+        defaults => {
+            'acl_profile' => 'passerby',
+        },
         target => \&_get_current,
     );
 
+    $router_get->add_route( 'employee/count',
+        defaults => {
+            'acl_profile' => 'admin',
+        },
+        target => \&_get_count,
+    );
+
+    $router_get->add_route( 'employee/count/:priv',
+        defaults => {
+            'acl_profile' => 'admin',
+        },
+        target => \&_get_count_priv,
+    );
+
     return "Employee GET router initialization complete";   
 }
 
@@ -150,12 +186,6 @@ The following functions implement actions for the various routes.
 sub _get_default {
     my ( %ARGS ) = @_;
 
-    # ACL check
-    if ( exists $ARGS{'acleid'} and exists $ARGS{'aclpriv'} ) {
-        my $acl = 'passerby'; # open to all
-        return check_acl( $acl, $ARGS{'aclpriv'} );
-    }
-
     my $uri = $ARGS{'context'}->{'uri'};
     $uri =~ s/\/*$//;
     my $server_status = App::Dochazka::REST::dbh::status;
@@ -168,14 +198,27 @@ sub _get_default {
                 'nick/:param' => {
                     link => "$uri/employee/nick/:param",
                     description => 'Search for employees by nick (either exact match or LIKE match using %)',
+                    acl_profile => 'admin',
                 },
                 'eid/:param' => {
                     link => "$uri/employee/eid/:param",
                     description => "Load a single employee by EID",
+                    acl_profile => 'admin',
                 },
                 'current' => {
                     link => "$uri/employee/current",
                     description => "Display profile of current employee (i.e., the employee you logged in as)",
+                    acl_profile => 'passerby',
+                },
+                'count' => {
+                    link => "$uri/employee/count",
+                    description => "Display total count of employees of all privilege levels",
+                    acl_profile => 'admin',
+                },
+                'count/:priv' => {
+                    link => "$uri/employee/count/:priv",
+                    description => "Display total count of employees of a particular privilege level ('admin', 'active', 'inactive', or 'passerby')",
+                    acl_profile => 'admin',
                 },
             },
         },
@@ -187,12 +230,6 @@ sub _get_nick {
     my ( %ARGS ) = @_;
     $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_nick" ); 
 
-    # ACL check
-    if ( exists $ARGS{'acleid'} and exists $ARGS{'aclpriv'} ) {
-        my $acl = 'admin'; # just us admins
-        return check_acl( $acl, $ARGS{'aclpriv'} );
-    }
-
     my $nick = $ARGS{'context'}->{'mapping'}->{'param'};
     my $status = App::Dochazka::REST::Model::Employee->
         select_multiple_by_nick( $nick );
@@ -211,17 +248,6 @@ sub _get_eid {
     my ( %ARGS ) = @_;
     $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_eid" ); 
 
-    # ACL check
-    if ( exists $ARGS{'acleid'} and exists $ARGS{'aclpriv'} ) {
-        my $acl = 'admin'; # just us admins
-        return check_acl( $acl, $ARGS{'aclpriv'} );
-    }
-
-    if ( exists $ARGS{'acleid'} and exists $ARGS{'aclpriv'} ) {
-        return $CELL->status_ok( 'DISPATCH_ACL_CHECK_OK' ) if $ARGS{aclpriv} eq 'admin';
-        return $CELL->status_not_ok( 'DISPATCH_ACL_CHECK_OK' );
-    }
-
     my $eid = $ARGS{'context'}->{'mapping'}->{'param'};
     App::Dochazka::REST::Model::Employee->load_by_eid( $eid );
 }
@@ -229,17 +255,30 @@ sub _get_eid {
 
 sub _get_current {
     my ( %ARGS ) = @_;
-    $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_eid" ); 
-
-    # ACL check
-    if ( exists $ARGS{'acleid'} and exists $ARGS{'aclpriv'} ) {
-        my $acl = 'passerby'; # everyone
-        return check_acl( $acl, $ARGS{'aclpriv'} );
-    }
+    $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_current" ); 
 
     my $current_emp = $ARGS{'context'}->{'current'};
     $CELL->status_ok( 'DISPATCH_EMPLOYEE_CURRENT', args => 
         [ $current_emp->{'nick'} ], payload => $current_emp );
 }
 
+
+sub _get_count {
+    my ( %ARGS ) = @_;
+    $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_count" ); 
+
+    my $result = noof_employees_by_priv( 'total' );
+    return $result;
+}
+
+
+sub _get_count_priv {
+    my ( %ARGS ) = @_;
+    $log->debug( "Entering App::Dochazka::REST::Dispatch::_get_count" ); 
+
+    my $priv = $ARGS{'context'}->{'mapping'}->{'priv'};
+    my $result = noof_employees_by_priv( $priv );
+    return $result;
+}
+
 1;
