@@ -54,11 +54,11 @@ App::Dochazka::REST::Model::Interval - activity intervals data model
 
 =head1 VERSION
 
-Version 0.117
+Version 0.122
 
 =cut
 
-our $VERSION = '0.117';
+our $VERSION = '0.122';
 
 
 
@@ -231,7 +231,8 @@ object, rewriting whatever was there before.  Returns a status object.
 
 sub load_by_iid {
     my ( $self, $iid ) = @_;
-    my $dbh = $self->dbh;
+    my $dbh = __PACKAGE__->SUPER::dbh;
+    die "Problem with database handle" unless $dbh->ping;
     my @attrs = ( 'iid', 'eid', 'aid', 'intvl', 'long_desc', 'remark' );
     my $sql = $site->SQL_INTERVAL_SELECT_BY_IID;
     my ( $result ) = $dbh->selectrow_hashref( $sql, undef, $iid );
