@@ -55,11 +55,11 @@ App::Dochazka::REST::Model::Schedule - schedule functions
 
 =head1 VERSION
 
-Version 0.117
+Version 0.122
 
 =cut
 
-our $VERSION = '0.117';
+our $VERSION = '0.122';
 
 
 
@@ -328,13 +328,16 @@ Field values are taken from the object. Returns a status object.
 sub insert {
     my ( $self ) = @_;
 
+    my $dbh = __PACKAGE__->SUPER::dbh;
+    die "Problem with database handle" unless $dbh->ping;
+
     # if the exact same schedule is already in the database, we
     # don't insert it again
-    $self->{sid} = $self->dbh->selectrow_array( $site->SQL_SCHEDULES_SELECT_SID, 
+    $self->{sid} = $dbh->selectrow_array( $site->SQL_SCHEDULES_SELECT_SID, 
                    undef, $self->{schedule} );    
     return $CELL->status_ok( "This schedule has SID " . $self->{sid} ) 
         if defined $self->{sid};
-    return $CELL->status_err( $self->dbh->errstr ) if $self->dbh->err;
+    return $CELL->status_err( $dbh->errstr ) if $dbh->err;
 
     # no exact match found, insert a new record
     my $status = cud(
@@ -386,9 +389,12 @@ sub load_by_sid {
     my ( $self, $sid ) = @_;
     my $status;
 
-    $self->dbh->{RaiseError} = 1;
+    my $dbh = __PACKAGE__->SUPER::dbh;
+    die "Problem with database handle" unless $dbh->ping;
+
+    $dbh->{RaiseError} = 1;
     try {
-        my $results = $self->dbh->selectrow_hashref( 
+        my $results = $dbh->selectrow_hashref( 
             $site->SQL_SCHEDULE_SELECT,
             undef,
             $sid 
@@ -400,9 +406,9 @@ sub load_by_sid {
             $status = $CELL->status_warn( 'DOCHAZKA_RECORDS_FETCHED', 0 );
         }
     } catch {
-        $status = $CELL->status_err( $self->dbh->errstr );
+        $status = $CELL->status_err( $dbh->errstr );
     };
-    $self->dbh->{RaiseError} = 0;
+    $dbh->{RaiseError} = 0;
 
     return $status;
 }
@@ -419,15 +425,11 @@ string associated with the SID. Returns undef if not found.
 =cut
 
 sub get_json {
+    my ( $sid ) = @_;
+    die "Problem with arguments in get_json" if not defined $sid;
 
-    my ( $dbh, $sid ) = @_;
-
-    if (  ( not defined( $dbh ) ) or
-          ( not $sid ) or
-          ( not $dbh->ping )  ) {
-        $CELL->status_err( "Problem with arguments in get_json" );
-        return;
-    }
+    my $dbh = __PACKAGE__->SUPER::dbh;
+    die "Problem with database handle" unless $dbh->ping;
 
     my ( $json) = $dbh->selectrow_array( $site->SQL_SCHEDULES_SELECT_SCHEDULE,
                                          undef,
